==> dolibarr-12.0.4.zip: dolibarr-12.0.4/htdocs/core/login/functions_empty.php <==
<?php
/* Copyright (C) 2010 Regis Houssin  <regis.houssin@inodbox.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *      \file       htdocs/core/login/functions_empty.php
 *      \ingroup    core
 *      \brief      Empty authentication functions for test
 */


/**
 * Check validity of user/password/entity
 * If test is ko, reason must be filled into $_SESSION["dol_loginmesg"]
 *
 * @param	string	$usertotest		Login
 * @param	string	$passwordtotest	Password
 * @param   int		$entitytotest   Number of instance (always 1 if module multicompany not enabled)
 * @return	string					Login if OK, '' if KO
 */
function check_user_password_empty($usertotest, $passwordtotest, $entitytotest)
{
	global $langs;

	dol_syslog("functions_empty::check_user_password_empty usertotest=".$usertotest);

	$login = '';
	$_SESSION["dol_loginmesg"] = $langs->trans("FailedToLogin");

	return $login;
}

==> dolibarr-21.0.2.zip: dolibarr-21.0.2/htdocs/core/login/functions_empty.php <==
<?php
/* Copyright (C) 2010 Regis Houssin  <regis.houssin@inodbox.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *      \file       htdocs/core/login/functions_empty.php
 *      \ingroup    core
 *      \brief      Empty authentication functions for test
 */


/**
 * Check validity of user/password/entity
 * If test is ko, reason must be filled into $_SESSION["dol_loginmesg"]
 *
 * @param	string	$usertotest		Login
 * @param	string	$passwordtotest	Password
 * @param   int		$entitytotest   Number of instance (always 1 if module multicompany not enabled)
 * @return	string					Login if OK, '' if KO
 */
function check_user_password_empty($usertotest, $passwordtotest, $entitytotest)
{
	global $langs;

	dol_syslog("functions_empty::check_user_password_empty usertotest=".$usertotest);

	$login = '';
	$_SESSION["dol_loginmesg"] = $langs->transnoentitiesnoconv("FailedToLogin");

	return $login;
}
